@@ -603,7 +603,7 @@ void TQMessageBox::init( int button0, int button1, int button2 )
 	    "Linux, and all major commercial Unix variants."
 	    "<br>TQt is also available for embedded devices.</p>"
 	    "<p>TQt is a Trolltech product. "
-	    "See <tt>http://www.trolltech.com/qt/</tt> "
+	    "See <tt>https://trinitydesktop.org/docs/qt3/</tt> "
 	    "for more information.</p>"
 	    ).arg( TQT_VERSION_STR );
 #endif
