@@ -260,7 +260,7 @@ int TQMenuData::insertAny( const TQString *text, const TQPixmap *pixmap,
     if ( id < 0 )				// -2, -3 etc.
 	id = get_seq_id();
 
-    register TQMenuItem *mi = new TQMenuItem;
+    TQMenuItem *mi = new TQMenuItem;
     TQ_CHECK_PTR( mi );
     mi->ident = id;
     if ( widget != 0 ) {
@@ -842,7 +842,7 @@ void TQMenuData::removeItemAt( int index )
 
 void TQMenuData::clear()
 {
-    register TQMenuItem *mi = mitems->first();
+    TQMenuItem *mi = mitems->first();
     while ( mi ) {
 	if ( mi->popup_menu )
 	    menuDelPopup( mi->popup_menu );
@@ -1041,7 +1041,7 @@ void TQMenuData::changeItem( int id, const TQPixmap &pixmap )
     TQMenuData *parent;
     TQMenuItem *mi = findItem( id, &parent );
     if ( mi ) {					// item found
-	register TQPixmap *i = mi->pixmap_data;
+	TQPixmap *i = mi->pixmap_data;
 	bool fast_refresh = i != 0 &&
 	    i->width() == pixmap.width() &&
 	    i->height() == pixmap.height() &&
@@ -1103,7 +1103,7 @@ void TQMenuData::changeItemIconSet( int id, const TQIconSet &icon )
     TQMenuData *parent;
     TQMenuItem *mi = findItem( id, &parent );
     if ( mi ) {					// item found
-	register TQIconSet *i = mi->iconset_data;
+	TQIconSet *i = mi->iconset_data;
 	bool fast_refresh = i != 0;
 	if ( !icon.isNull() )
 	    mi->iconset_data = new TQIconSet( icon );
