@@ -290,12 +290,12 @@
         <translation>LTR</translation>
     </message>
     <message>
-        <source>Executable &apos;%1&apos; requires Qt %2, found Qt %3.</source>
-        <translation>El programa &apos;%1&apos; requiere Qt %2, se encontró Qt %3.</translation>
+        <source>Executable &apos;%1&apos; requires TQt %2, found TQt %3.</source>
+        <translation>El programa &apos;%1&apos; requiere TQt %2, se encontró TQt %3.</translation>
     </message>
     <message>
-        <source>Incompatible Qt Library Error</source>
-        <translation>Error: Biblioteca Qt incompatible</translation>
+        <source>Incompatible TQt Library Error</source>
+        <translation>Error: Biblioteca TQt incompatible</translation>
     </message>
 </context>
 <context>
@@ -1263,8 +1263,8 @@ a
         <translation>&amp;Ignorar</translation>
     </message>
     <message>
-        <source>&lt;h3&gt;About Qt&lt;/h3&gt;&lt;p&gt;This program uses Qt version %1.&lt;/p&gt;&lt;p&gt;Qt is a C++ toolkit for multiplatform GUI &amp;amp; application development.&lt;/p&gt;&lt;p&gt;Qt provides single-source portability across MS&amp;nbsp;Windows, Mac&amp;nbsp;OS&amp;nbsp;X, Linux, and all major commercial Unix variants.&lt;br&gt;Qt is also available for embedded devices.&lt;/p&gt;&lt;p&gt;Qt is a Trolltech product. See &lt;tt&gt;http://www.trolltech.com/qt/&lt;/tt&gt; for more information.&lt;/p&gt;</source>
-        <translation>&lt;h3&gt;Acerca de Qt&lt;/h3&gt;&lt;p&gt;Este programa usa Qt versión %1.&lt;/p&gt;&lt;p&gt;Qt es un conjunto de herramientas en C++ para el desarrollo de aplicaciones e interfaces gráficas de usuario (GUI) multiplataforma.&lt;/p&gt;&lt;p&gt;Qt proporciona portabilidad a nivel de código fuente entre MS&amp;nbsp;Windows, Mac&amp;nbsp;OS&amp;nbsp;X, Linux y las variantes comerciales de Unix más importantes.&lt;br&gt;Qt también está disponible para dispositivos empotrados.&lt;/p&gt;&lt;p&gt;Qt es un producto Trolltech. Vea &lt;tt&gt;http://www.trolltech.com/qt/&lt;/tt&gt; para más información.&lt;/p&gt;</translation>
+        <source>&lt;h3&gt;About Qt&lt;/h3&gt;&lt;p&gt;This program uses TQt version %1.&lt;/p&gt;&lt;p&gt;Qt is a C++ toolkit for multiplatform GUI &amp;amp; application development.&lt;/p&gt;&lt;p&gt;Qt provides single-source portability across MS&amp;nbsp;Windows, Mac&amp;nbsp;OS&amp;nbsp;X, Linux, and all major commercial Unix variants.&lt;br&gt;Qt is also available for embedded devices.&lt;/p&gt;&lt;p&gt;Qt is a Trolltech product. See &lt;tt&gt;https://trinitydesktop.org/docs/qt3/&lt;/tt&gt; for more information.&lt;/p&gt;</source>
+        <translation>&lt;h3&gt;Acerca de Qt&lt;/h3&gt;&lt;p&gt;Este programa usa TQt versión %1.&lt;/p&gt;&lt;p&gt;Qt es un conjunto de herramientas en C++ para el desarrollo de aplicaciones e interfaces gráficas de usuario (GUI) multiplataforma.&lt;/p&gt;&lt;p&gt;Qt proporciona portabilidad a nivel de código fuente entre MS&amp;nbsp;Windows, Mac&amp;nbsp;OS&amp;nbsp;X, Linux y las variantes comerciales de Unix más importantes.&lt;br&gt;Qt también está disponible para dispositivos empotrados.&lt;/p&gt;&lt;p&gt;Qt es un producto Trolltech. Vea &lt;tt&gt;https://trinitydesktop.org/docs/qt3/&lt;/tt&gt; para más información.&lt;/p&gt;</translation>
     </message>
 </context>
 <context>
